Module: Signnow::Operations::All::ClassMethods
- Defined in:
- lib/signnow/operations/all.rb
Instance Method Summary collapse
-
#all(attributes = {}) ⇒ Array
Retrieves all available objects from the Signnow API.
-
#options_for_all(attributes) ⇒ Hash
Options for all overwrite this in the model to set security.
Instance Method Details
#all(attributes = {}) ⇒ Array
Retrieves all available objects from the Signnow API
9 10 11 12 |
# File 'lib/signnow/operations/all.rb', line 9 def all(attributes = {}) response = Signnow.request(:get, nil, api_all_url , attributes, (attributes)) results_from response end |
#options_for_all(attributes) ⇒ Hash
Options for all overwrite this in the model to set security
26 27 28 29 30 31 32 33 |
# File 'lib/signnow/operations/all.rb', line 26 def (attributes) access_token = attributes.delete(:access_token) raise AuthenticationError unless access_token { auth_type: :user_token, auth_token: access_token } end |