Module: Signnow::Operations::Create::ClassMethods
- Defined in:
- lib/signnow/operations/create.rb
Instance Method Summary collapse
-
#create(attributes) ⇒ Object
Creates a new object.
-
#options_for_create ⇒ Hash
Options for create overwrite this in the model if the api is not well named.
Instance Method Details
#create(attributes) ⇒ Object
Creates a new object
8 9 10 11 |
# File 'lib/signnow/operations/create.rb', line 8 def create(attributes) response = Signnow.request(:post, nil, api_create_url, attributes, ) self.new(response) end |
#options_for_create ⇒ Hash
Options for create overwrite this in the model if the api is not well named
25 26 27 |
# File 'lib/signnow/operations/create.rb', line 25 def { auth_type: :basic } end |