Module: Signnow::Operations::DownloadLink::ClassMethods
- Defined in:
- lib/signnow/operations/download_link.rb
Instance Method Summary collapse
-
#download_link(attributes = {}) ⇒ Object
Request a one time download.
-
#options_for_download_link(attributes) ⇒ Hash
Options for show overwrite this in the model to set security.
Instance Method Details
#download_link(attributes = {}) ⇒ Object
Request a one time download
7 8 9 10 |
# File 'lib/signnow/operations/download_link.rb', line 7 def download_link(attributes={}) response = Signnow.request(:post, nil, api_download_link_url(attributes[:id]), {}, (attributes)) response['link'] end |
#options_for_download_link(attributes) ⇒ Hash
Options for show overwrite this in the model to set security
27 28 29 30 31 32 33 |
# File 'lib/signnow/operations/download_link.rb', line 27 def (attributes) raise AuthenticationError unless attributes[:access_token] { auth_type: :user_token, auth_token: attributes[:access_token] } end |