Module: Signnow::Operations::Show::ClassMethods
- Defined in:
- lib/signnow/operations/show.rb
Instance Method Summary collapse
-
#options_for_show(attributes) ⇒ Hash
Options for show overwrite this in the model to set security.
-
#show(attributes = {}) ⇒ Signnow::Base
Shows a given object.
Instance Method Details
#options_for_show(attributes) ⇒ Hash
Options for show overwrite this in the model to set security
28 29 30 31 32 33 34 |
# File 'lib/signnow/operations/show.rb', line 28 def (attributes) raise AuthenticationError unless attributes[:access_token] { auth_type: :user_token, auth_token: attributes[:access_token] } end |
#show(attributes = {}) ⇒ Signnow::Base
Shows a given object
9 10 11 12 |
# File 'lib/signnow/operations/show.rb', line 9 def show(attributes={}) response = Signnow.request(:get, nil, api_show_url(attributes[:id]), {}, (attributes)) self.new(response) end |